//
//  SingleChannelQueryView.swift
//  SampleApp
//
//  Created by Nishan Niraula on 17/8/2565 BE.
//  Copyright © 2565 BE David Zhang. All rights reserved.
//

import SwiftUI
import AmitySDK

struct SingleChannelQueryView: View {
    
    @State var channelId = ""
    @State var channelInfo = ""
    
    let viewModel = ChannelQueryViewModel()
    
    var body: some View {
        VStack {
            TextField("Enter Channel Id", text: $channelId)
                .autocapitalization(.none)
                .padding()
                .frame(height: 50)
                .background(Color(UIColor.systemGroupedBackground))
            
            Button(action: {
                self.viewModel.fetchChannelInfo(id: self.channelId) { info in
                    self.channelInfo = info
                }
                
            }) {
                Text("Query Channel")
            }
            .frame(width: 200, height: 40)
            .foregroundColor(Color.white)
            .background(Color.blue)
            .cornerRadius(16)
            .padding(.top, 20)
            
            Button(action: {
                self.viewModel.fetchChannelAvatar { imageInfo in
                    self.channelInfo = self.channelInfo + imageInfo
                }
            }) {
                Text("Test Avatar")
            }
            .frame(width: 200, height: 40)
            .foregroundColor(Color.white)
            .background(Color.blue)
            .cornerRadius(16)
            .padding(.top, 20)
            
            Text("Test if avatar is mapped correctly to this channel.").font(.callout)
                .foregroundColor(Color(UIColor.secondaryLabel))
                .padding(.top, 8)
            
            ScrollView {
                Text(channelInfo)
                    .padding(.top, 16)
            }
            
            Spacer()
        }.padding()
            .navigationBarTitle("Get Channel", displayMode: .inline)
        
    }
}

struct SingleChannelQueryView_Previews: PreviewProvider {
    static var previews: some View {
        SingleChannelQueryView()
    }
}

class ChannelQueryViewModel {
    
    var token: AmityNotificationToken?
    let channelRepo = AmityChannelRepository(client: AmityManager.shared.client!)
    var fetchedChannel: AmityObject<AmityChannel>?
    
    func fetchChannelInfo(id: String, completion: @escaping (String) -> Void) {
        fetchedChannel = channelRepo.getChannel(id)
        token = fetchedChannel?.observe { liveObject, error in
            
            let dataStatus = liveObject.dataStatus.description
            if let err = error {
                completion("Error Occurred: \(err.localizedDescription) Data Status: \(dataStatus)")
            } else {
                let modelDescription = liveObject.snapshot?.modelDescription
                completion(modelDescription ?? "")
            }
        }
    }
    
    func fetchChannelAvatar(completion: @escaping (String) -> Void) {
        guard let channel = fetchedChannel else { return }
        
        if let avatarData = channel.snapshot?.getAvatarInfo() {
            let fileId = avatarData.fileId
            let fileAttributes = avatarData.attributes.description
            
            let fileInfo =
            """
            Mapped Data:
            
            FileId: \(fileId)
            Attributes: \(fileAttributes)
            """
            
            completion(fileInfo)
        } else {
            completion("\n\nThis channel does not contain any avatar")
        }
    }
}
