//
//  NotificationLogViewController.swift
//  SampleApp
//
//  Created by Nutchaphon Rewik on 7/2/2565 BE.
//  Copyright © 2565 BE David Zhang. All rights reserved.
//

import UIKit
import Combine

class NotificationLogViewController: UIViewController {

    private var payloads: [String] = []
    
    @IBOutlet private weak var tableView: UITableView!
    
    private var cancellable: AnyCancellable?


    override func viewDidLoad() {
        super.viewDidLoad()
        title = "Push Notification Log"
        cancellable = AmityManager.shared.$pushPayloads.sink { [weak self] payloads in
            self?.payloads = payloads.reversed()
            self?.tableView.reloadData()
        }
        tableView.dataSource = self
        tableView.delegate = self
        tableView.rowHeight = UITableView.automaticDimension
        tableView.register(UITableViewCell.self, forCellReuseIdentifier: "cell")
        let clearNotificationButton = UIBarButtonItem(image: UIImage(systemName: "trash"), style: .plain, target: self, action: #selector(clearNotification))
        navigationItem.rightBarButtonItems = [clearNotificationButton]
    }
    
    @objc func clearNotification() {
        AmityManager.shared.clearNotificationPayloads()
    }
    
}

extension NotificationLogViewController: UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        payloads.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "cell", for: indexPath)
        let jsonString = payloads[indexPath.row]
        
        cell.textLabel?.text = jsonString
        cell.textLabel?.numberOfLines = 0
        return cell
    }
    
}

extension NotificationLogViewController: UITableViewDelegate {
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        tableView.deselectRow(at: indexPath, animated: true)
        UIPasteboard.general.string = payloads[indexPath.row]
        let alertController = UIAlertController(title: "Payload Copied", message: nil, preferredStyle: .alert)
        let ok = UIAlertAction(title: "OK", style: .default, handler: nil)
        alertController.addAction(ok)
        present(alertController, animated: true, completion: nil)
    }
    
}
